pub(crate) enum Content<'de> {
Show 24 variants
Bool(bool),
U8(u8),
U16(u16),
U32(u32),
U64(u64),
U128(u128),
I8(i8),
I16(i16),
I32(i32),
I64(i64),
I128(i128),
F32(f32),
F64(f64),
Char(char),
String(String),
Str(&'de str),
ByteBuf(Vec<u8>),
Bytes(&'de [u8]),
None,
Some(Box<Content<'de>>),
Unit,
Newtype(Box<Content<'de>>),
Seq(Vec<Content<'de>>),
Map(Vec<(Content<'de>, Content<'de>)>),
}Expand description
Used from generated code to buffer the contents of the Deserializer when deserializing untagged enums and internally tagged enums.
Not public API. Use serde-value instead.
Variants
Bool(bool)
U8(u8)
U16(u16)
U32(u32)
U64(u64)
U128(u128)
I8(i8)
I16(i16)
I32(i32)
I64(i64)
I128(i128)
F32(f32)
F64(f64)
Char(char)
String(String)
Str(&'de str)
ByteBuf(Vec<u8>)
Bytes(&'de [u8])
None
Some(Box<Content<'de>>)
Unit
Newtype(Box<Content<'de>>)
Seq(Vec<Content<'de>>)
Map(Vec<(Content<'de>, Content<'de>)>)
Implementations
Sourceimpl Content<'_>
impl Content<'_>
fn unexpected<'a>(&'a self, buf: &'a mut [u8; 58]) -> Unexpected<'a>